@@ -4,7 +4,7 @@ from hestia_earth.earth_engine.coordinates import run
 from hestia_earth.earth_engine.gee_utils import load_region, load_geometry, area_km2
 
 
-ENABLED = os.environ.get('VALIDATE_SPATIAL', 'true') == 'true'
+ENABLED = os.getenv('VALIDATE_SPATIAL', 'true') == 'true'
 gee_init = False
 
 
