@@ -7,7 +7,7 @@ def _add_handler(logger: logging.Logger, formatter: logging.Formatter, handler:
     logger.addHandler(handler)
 
 
-LOG_LEVEL = os.environ.get('LOG_LEVEL', 'INFO')
+LOG_LEVEL = os.getenv('LOG_LEVEL', 'INFO')
 logger = logging.getLogger('hestia_earth.validation')
 logger.setLevel(logging.getLevelName(LOG_LEVEL))
 
