@@ -2,7 +2,7 @@ import os
 
 from .mock_search import mock as mock_search
 
-ENABLED = os.environ.get('ENABLE_MOCKING', 'false') == 'true'
+ENABLED = os.getenv('ENABLE_MOCKING', 'false') == 'true'
 
 
 def auto_mock():
