@@ -7,7 +7,7 @@ from hestia_earth.utils.lookup import get_table_value, download_lookup, column_n
 from hestia_earth.validation.utils import _find_linked_node, _value_average, _list_sum_terms
 from hestia_earth.validation.terms import get_crop_residue_terms
 from .shared import (
-    validate_dates, validate_list_dates, validate_date_lt_today, validate_list_min_below_max,
+    validate_dates, validate_list_dates, validate_list_dates_after, validate_date_lt_today, validate_list_min_below_max,
     validate_list_term_percent, validate_linked_source_privacy, validate_list_dates_length, validate_list_date_lt_today,
     validate_list_model, validate_list_model_config, validate_list_dates_format,
     validate_list_duplicate_values, validate_private_has_source, validate_list_value_between_min_max
@@ -200,6 +200,7 @@ def validate_cycle(cycle: dict, node_map: dict = {}):
         ([
             validate_list_model(cycle, 'emissions'),
             validate_list_dates(cycle, 'emissions'),
+            validate_list_dates_after(cycle, 'startDate', 'emissions', ['startDate', 'endDate']),
             validate_list_dates_format(cycle, 'emissions'),
             validate_list_min_below_max(cycle, 'emissions'),
             validate_list_value_between_min_max(cycle, 'emissions'),
@@ -213,6 +214,7 @@ def validate_cycle(cycle: dict, node_map: dict = {}):
         ] if len(cycle.get('emissions', [])) > 0 else []) +
         ([
             validate_list_dates(cycle, 'inputs'),
+            validate_list_dates_after(cycle, 'startDate', 'inputs', ['startDate', 'endDate', 'dates']),
             validate_list_dates_format(cycle, 'inputs'),
             validate_list_dates_length(cycle, 'inputs'),
             validate_list_date_lt_today(cycle, 'inputs', ['startDate', 'endDate']),
@@ -228,6 +230,7 @@ def validate_cycle(cycle: dict, node_map: dict = {}):
         ] if len(cycle.get('inputs', [])) > 0 else []) +
         ([
             validate_list_dates(cycle, 'products'),
+            validate_list_dates_after(cycle, 'startDate', 'products', ['startDate', 'endDate', 'dates']),
             validate_list_dates_format(cycle, 'products'),
             validate_list_dates_length(cycle, 'products'),
             validate_list_date_lt_today(cycle, 'products', ['startDate', 'endDate']),
@@ -250,6 +253,7 @@ def validate_cycle(cycle: dict, node_map: dict = {}):
         ] if len(cycle.get('products', [])) > 0 else []) +
         ([
             validate_list_dates(cycle, 'practices'),
+            validate_list_dates_after(cycle, 'startDate', 'practices', ['startDate', 'endDate', 'dates']),
             validate_list_dates_format(cycle, 'practices'),
             validate_list_date_lt_today(cycle, 'practices', ['startDate', 'endDate']),
             validate_list_min_below_max(cycle, 'practices'),
@@ -269,6 +273,7 @@ def validate_cycle(cycle: dict, node_map: dict = {}):
         ] if len(cycle.get('practices', [])) > 0 else []) +
         ([
             validate_list_dates(cycle, 'transformations'),
+            validate_list_dates_after(cycle, 'startDate', 'transformations', ['startDate', 'endDate']),
             validate_list_dates_format(cycle, 'transformations'),
             validate_list_date_lt_today(cycle, 'transformations', ['startDate', 'endDate']),
             validate_previous_transformation(cycle.get('transformations')),
