@@ -1,3 +1,4 @@
+from hestia_earth.schema import NodeType
 from hestia_earth.utils.model import find_term_match
 from hestia_earth.utils.tools import flatten
 
@@ -22,7 +23,37 @@ def validate_linked_cycle_product(impact_assessment: dict, cycle: dict):
             'product': product,
             'node': {
                 'type': 'Cycle',
-                'id': cycle.get('id')
+                'id': cycle.get('id', cycle.get('@id'))
+            }
+        }
+    }
+
+
+def _filter_same_cycle(cycle: dict):
+    def filter(impact_assessment: dict):
+        ia_cycle = impact_assessment.get('cycle', {})
+        return any([
+            ia_cycle.get('id') and ia_cycle.get('id') == cycle.get('id'),
+            ia_cycle.get('@id') and ia_cycle.get('@id') == cycle.get('@id')
+        ])
+    return filter
+
+
+def validate_single_linked_impact_assessment(impact_assessment: dict, node_map: dict, cycle: dict):
+    product = impact_assessment.get('product', {})
+    product_id = product.get('@id')
+    uploaded_impact_assessments = node_map.get(NodeType.IMPACTASSESSMENT.value).values()
+    related_impact_assessments = list(filter(_filter_same_cycle(cycle), uploaded_impact_assessments))
+    same_product_id = list(filter(lambda v: v.get('product', {}).get('@id') == product_id, related_impact_assessments))
+    return len(same_product_id) == 1 or {
+        'level': 'error',
+        'dataPath': '.product',
+        'message': 'multiple ImpactAssessment are associated with the same Product of the same Cycle',
+        'params': {
+            'product': product,
+            'node': {
+                'type': 'Cycle',
+                'id': cycle.get('id', cycle.get('@id'))
             }
         }
     }
@@ -54,6 +85,7 @@ def validate_impact_assessment(impact_assessment: dict, node_map: dict = {}):
         validate_is_region(impact_assessment) if 'region' in impact_assessment else True,
         validate_region_in_country(impact_assessment) if 'region' in impact_assessment else True,
         validate_linked_cycle_product(impact_assessment, cycle) if cycle else True,
+        validate_single_linked_impact_assessment(impact_assessment, node_map, cycle) if cycle else True
     ] + flatten(
         ([
             validate_list_min_below_max(impact_assessment, 'emissionsResourceUse'),
