@@ -1,4 +1,5 @@
 from functools import reduce
+from hestia_earth.schema import TermTermType
 from hestia_earth.utils.lookup import download_lookup, get_table_value, column_name
 from hestia_earth.utils.tools import list_sum, non_empty_list, safe_parse_float, flatten
 
@@ -10,17 +11,17 @@ from .shared import need_validate_coordinates, value_difference
 SOIL_TEXTURE_IDS = ['sandContent', 'siltContent', 'clayContent']
 
 
-def _rainfallAnnual(site: dict, measurement: dict):
-    from hestia_earth.models.spatial.rainfallAnnual import _run
+def _precipitationAnnual(site: dict, measurement: dict):
+    from hestia_earth.models.spatial.precipitationAnnual import _run
     year = _node_year(measurement)
     result = _run(site, year) if year and need_validate_coordinates(site) else None
     return result
 
 
 MEASUREMENTS_MODELS = {
-    'rainfallAnnual': [
+    'precipitationAnnual': [
         'spatial',
-        _rainfallAnnual
+        _precipitationAnnual
     ]
 }
 
@@ -113,13 +114,12 @@ def validate_depths(measurements: list):
 
 def validate_required_depths(site: dict, list_key: str):
     values = site.get(list_key, [])
-    has_depths = any(filter(
+    required_has_depths = any(filter(
         lambda v: v.get('term', {}).get('@id') in SOIL_TEXTURE_IDS and (
             v.get('depthUpper') or v.get('depthLower')
         ),
         values
     ))
-    level = 'error' if has_depths else 'warning'
 
     def validate(values: tuple):
         index, measurement = values
@@ -129,6 +129,7 @@ def validate_required_depths(site: dict, list_key: str):
         lookup = download_lookup(f"{term_type}.csv")
         with_depth = get_table_value(lookup, 'termid', term_id, column_name('recommendAddingDepth'))
         has_depths = measurement.get('depthUpper') is not None and measurement.get('depthLower') is not None
+        level = 'error' if all([required_has_depths, term_type == TermTermType.SOILTEXTURE.value]) else 'warning'
         return not with_depth or with_depth == '' or has_depths or {
             'level': level,
             'dataPath': f".{list_key}[{index}]",
