@@ -51,10 +51,43 @@ def validate_list_date_lt_today(node: dict, list_key: str, node_keys: list):
     return _filter_list_errors(flatten(map(validate, enumerate(node.get(list_key, [])))))
 
 
-def validate_dates(node: dict):
-    start = node.get('startDate')
-    end = node.get('endDate')
-    return start is None or end is None or (len(start) <= 7 and len(end) <= 7 and end >= start) or end > start
+def is_date_after(min_date: str, date: str):
+    return min_date is None or date is None or (
+        len(min_date) <= 7 and len(date) <= 7 and date >= min_date
+    ) or date > min_date
+
+
+def validate_list_dates_after(node: dict, node_key: str, list_key: str, list_key_fields: list[str]):
+    min_date = node.get(node_key)
+
+    def validate_field_list(blank_node: dict, index: int, field: str, field_index: int):
+        date = blank_node.get(field)[field_index]
+        return is_date_after(min_date, date) or {
+            'level': 'warning',
+            'dataPath': f".{list_key}[{index}].{field}[{field_index}]",
+            'message': f"must be greater than {node.get('type', node.get('@type'))} {node_key}"
+        }
+
+    def validate_field(blank_node: dict, index: int, field: str):
+        date = blank_node.get(field)
+        return [
+            validate_field_list(blank_node, index, field, field_index) for field_index in range(0, len(date))
+        ] if isinstance(date, list) else (
+            is_date_after(min_date, date) or {
+                'level': 'warning',
+                'dataPath': f".{list_key}[{index}].{field}",
+                'message': f"must be greater than {node.get('type', node.get('@type'))} {node_key}"
+            }
+        )
+
+    def validate(values: tuple):
+        index, blank_node = values
+        return _filter_list_errors(flatten([validate_field(blank_node, index, field) for field in list_key_fields]))
+
+    return _filter_list_errors(map(validate, enumerate(node.get(list_key, []))))
+
+
+def validate_dates(node: dict): return is_date_after(node.get('startDate'), node.get('endDate'))
 
 
 def validate_list_dates(node: dict, list_key: str):
@@ -270,9 +303,9 @@ def validate_area(node: dict):
         expected_value = get_geojson_area(node.get('boundary'))
         delta = value_difference(value, expected_value) if expected_value else 0
         return delta < threshold or {
-            'level': 'error',
+            'level': 'warning',
             'dataPath': '.area',
-            'message': f"must be equal to boundary (~{expected_value})",
+            'message': 'should be equal to boundary',
             'params': {
                 'current': value,
                 'expected': expected_value,
