@@ -4,7 +4,7 @@ from hestia_earth.utils.tools import flatten
 from hestia_earth.validation.gee import fetch_data
 from .shared import (
     validate_dates, validate_list_dates, validate_list_dates_format, validate_list_min_below_max,
-    validate_list_min_max_lookup,
+    validate_list_min_max_lookup, validate_list_dates_after,
     validate_region_in_country, validate_country, validate_is_region, validate_coordinates, need_validate_coordinates,
     validate_area, need_validate_area, validate_list_term_percent, validate_linked_source_privacy,
     validate_list_date_lt_today, validate_date_lt_today, validate_area_size,
@@ -119,6 +119,7 @@ def validate_site(site: dict, node_map: dict = {}):
         ] if 'infrastructure' in site else []) +
         ([
             validate_list_dates(site, 'measurements'),
+            validate_list_dates_after(site, 'startDate', 'measurements', ['startDate', 'endDate', 'dates']),
             validate_list_dates_format(site, 'measurements'),
             validate_list_date_lt_today(site, 'measurements', ['startDate', 'endDate']),
             validate_list_min_below_max(site, 'measurements'),
@@ -139,6 +140,7 @@ def validate_site(site: dict, node_map: dict = {}):
         ] if len(site.get('measurements', [])) > 0 else []) +
         ([
             validate_list_dates(site, 'practices'),
+            validate_list_dates_after(site, 'startDate', 'practices', ['startDate', 'endDate', 'dates']),
             validate_list_dates_format(site, 'practices'),
             validate_list_date_lt_today(site, 'practices', ['startDate', 'endDate']),
             validate_list_min_below_max(site, 'practices'),
