@@ -207,10 +207,18 @@ SD = 1000
 
 
 @patch(f"{class_path}.get_post", return_value=(MU, SD))
-def test_validate_product_yield_valid_with_posterior(*args):
+def test_validate_product_yield_valid(*args):
     # no products should be valid
     assert validate_product_yield({'products': []}, {}, 'products') is True
 
+    # no value on products should be valid
+    with open(f"{fixtures_path}/product/yield/no-value.json") as f:
+        cycle = json.load(f)
+    assert validate_product_yield(cycle, cycle.get('site')) is True
+
+
+@patch(f"{class_path}.get_post", return_value=(MU, SD))
+def test_validate_product_yield_valid_with_posterior(*args):
     with open(f"{fixtures_path}/product/yield/valid.json") as f:
         cycle = json.load(f)
     assert validate_product_yield(cycle, cycle.get('site')) is True
