@@ -11,7 +11,7 @@ from hestia_earth.validation.validators.shared import (
     value_difference, is_value_different, validate_list_model, validate_list_model_config,
     validate_properties_same_length, validate_list_duplicate_values, validate_nodes_duplicates, validate_area_size,
     validate_boundary_size, need_validate_boundary_size, validate_region_size, need_validate_region_size,
-    validate_private_has_source, validate_list_value_between_min_max
+    validate_private_has_source, validate_list_value_between_min_max, validate_list_dates_after
 )
 from hestia_earth.validation.validators.cycle import PRODUCTS_MODEL_CONFIG
 
@@ -66,7 +66,7 @@ def test_validate_list_dates_length_invalid():
     }
 
 
-def test_validate_emissions_dates_valid():
+def test_validate_list_dates_valid():
     node = {
         'list': [{
             'startDate': '2020-01-01',
@@ -76,7 +76,7 @@ def test_validate_emissions_dates_valid():
     assert validate_list_dates(node, 'list') is True
 
 
-def test_validate_emissions_dates_invalid():
+def test_validate_list_dates_invalid():
     node = {
         'list': [{
             'startDate': '2020-01-02',
@@ -90,6 +90,49 @@ def test_validate_emissions_dates_invalid():
     }
 
 
+def validate_list_dates_after_valid():
+    node = {
+        'type': 'Cycle',
+        'date': '2020-01-01',
+        'list': [{
+            'start': '2020-01-02',
+            'end': '2020-01-03',
+            'dates': [
+                '2020-01-02',
+                '2020-01-03'
+            ]
+        }]
+    }
+    assert validate_list_dates_after(node, 'date', 'list', ['start', 'end', 'dates']) is True
+
+
+def test_validate_list_dates_after_invalid():
+    node = {
+        'type': 'Cycle',
+        'date': '2020-01-01',
+        'list': [{
+            'start': '2020-01-02',
+            'end': '2019-01-01',
+            'dates': [
+                '2020-01-02',
+                '2019-01-01'
+            ]
+        }]
+    }
+    assert validate_list_dates_after(node, 'date', 'list', ['start', 'end', 'dates']) == [
+        {
+            'level': 'warning',
+            'dataPath': '.list[0].end',
+            'message': 'must be greater than Cycle date'
+        },
+        {
+            'level': 'warning',
+            'dataPath': '.list[0].dates[1]',
+            'message': 'must be greater than Cycle date'
+        }
+    ]
+
+
 def test_validate_list_min_below_max_valid():
     node = {
         'list': [{
@@ -325,9 +368,9 @@ def test_validate_area_invalid():
     with open(f"{fixtures_path}/shared/area/invalid.json") as f:
         node = json.load(f)
     assert validate_area(node) == {
-        'level': 'error',
+        'level': 'warning',
         'dataPath': '.area',
-        'message': 'must be equal to boundary (~13.8)',
+        'message': 'should be equal to boundary',
         'params': {
             'current': 4.5,
             'expected': 13.8,
